@@ -10,7 +10,7 @@ BEGIN {
 }
 
 use DateTime;
-use ElasticSearch;
+use Elasticsearch::Compat;
 use JSON;
 use LWP::Simple;
 use Getopt::Long;
@@ -95,7 +95,7 @@ $TARGET .= ":$CFG{port}";
 debug("Target is: $TARGET");
 debug_var(\%CFG);
 
-my $es = ElasticSearch->new(
+my $es = Elasticsearch::Compat->new(
     servers   => [ $TARGET ],
     transport => 'http',
     timeout   => 0,     # Do Not Timeout
@@ -228,7 +228,7 @@ es-daily-index-maintenance.pl - Run to prune old indexes and optimize existing
 
 =head1 VERSION
 
-version 1.3
+version 1.4
 
 =head1 SYNOPSIS
 
